/* 
 * This work is licensed under a Creative Commons 
 * Attribution-Noncommercial-Share Alike 3.0 United States License.
 * 
 *    http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 * 
 * You are free:
 * 
 *    to Share - to copy, distribute, display, and perform the work
 *    to Remix - to make derivative works
 * 
 * Under the following conditions:
 * 
 *    Attribution. You must attribute the work in the manner specified by the
 *    author or licensor (but not in any way that suggests that they endorse you
 *    or your use of the work).
 * 
 *    Noncommercial. You may not use this work for commercial purposes.
 * 
 *    Share Alike. If you alter, transform, or build upon this work, you may
 *    distribute the resulting work only under the same or similar license to
 *    this one.
 * 
 * For any reuse or distribution, you must make clear to others the license
 * terms of this work. The best way to do this is with a link to this web page.
 * 
 * Any of the above conditions can be waived if you get permission from the
 * copyright holder.
 * 
 * Apart from the remix rights granted under this license, nothing in this
 * license impairs or restricts the author's moral rights.
 */


/**
 * @file
 *
 * @author Joseph Schlecht
 *
 * @brief Processes model category parameters.
 */


#include <config.h>

#include <iostream>
#include <cstdlib>

#include <inttypes.h>

#include <jwsc/base/error.h>

#include <jwsc++/base/option.h>
#include <jwsc++/base/exception.h>

#include "sampler.h"
#include "onscreen.h"
#include "offscreen.h"
#include "options.h"


/** @brief Prints the usage of the program. */
void print_usage()
{
    std::cerr << "usage: furniture-recognize OPTIONS\n";
    std::cerr << "where OPTIONS is one or more of the following:\n";
}


/** @brief Main function for the @em furniture program. */
int main(int argc, const char** argv)
{
    using std::list;

    int rstatus = EXIT_SUCCESS;

    Sampler* sampler = 0;
    Sampler::Parameters* params = 0;

    try
    {
        process_furniture_options(argc, argv);

        if (opts.interactive)
        {
            Onscreen::enable(argc, argv, "Furniture");
            create_rec_sampler_and_params(&sampler, &params);
            Onscreen::start(sampler, params);
        }
        else
        {
            Offscreen::enable();
            create_rec_sampler_and_params(&sampler, &params);
            sampler->run(params, opts.iterations);
            write_results(params);
            Offscreen::disable();
        }
    }
    catch (jwscxx::base::Exception e)
    {
        cerr << "furniture-recognize: ";
        e.print();
        rstatus = EXIT_FAILURE;
    }

    delete sampler;
    delete params;

    clean_up_furniture();

    if (jwsc::get_num_unhandled_errors() > 0)
    {
        std::cerr << "furniture: Unhandled errors: " 
                  << jwsc::get_num_unhandled_errors();
        rstatus = EXIT_FAILURE;
    }

    return rstatus;
}
