/**
 * This work is licensed under a Creative Commons 
 * Attribution-Noncommercial-Share Alike 3.0 United States License.
 * 
 *    http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 * 
 * You are free:
 * 
 *    to Share - to copy, distribute, display, and perform the work
 *    to Remix - to make derivative works
 * 
 * Under the following conditions:
 * 
 *    Attribution. You must attribute the work in the manner specified by the
 *    author or licensor (but not in any way that suggests that they endorse you
 *    or your use of the work).
 * 
 *    Noncommercial. You may not use this work for commercial purposes.
 * 
 *    Share Alike. If you alter, transform, or build upon this work, you may
 *    distribute the resulting work only under the same or similar license to
 *    this one.
 * 
 * For any reuse or distribution, you must make clear to others the license
 * terms of this work. The best way to do this is with a link to this web page.
 * 
 * Any of the above conditions can be waived if you get permission from the
 * copyright holder.
 * 
 * Apart from the remix rights granted under this license, nothing in this
 * license impairs or restricts the author's moral rights.
 */


/**
 * @file
 *
 * @author Joseph Schlecht
 *
 * @brief Functions to enable or disable different types of offscreen
 * rendering.
 */


#ifndef FURNITURE_OFFSCREEN_H
#define FURNITURE_OFFSCREEN_H


#include <config.h>

#include <jwsc++/base/exception.h>


namespace Offscreen
{

    /** @brief Enables the offscreen rendering context. */
    void enable() throw (jwscxx::base::Exception);


    /** @brief Returns whether offscreen rendering is enabled. */
    bool enabled();


    /** @brief Disables the offscreen rendering context. */
    void disable() throw (jwscxx::base::Exception);


    /** 
     * @brief Activates the main offscreen rendering context for the current
     * thread.
     */
    void activate() throw (jwscxx::base::Exception);


    /** 
     * @brief Deactivates the main offscreen rendering context for the current
     * thread.
     */
    void deactivate() throw (jwscxx::base::Exception);


    /** 
     * @brief Reactivates the main offscreen rendering context for the current
     * thread.
     */
    void reactivate() throw (jwscxx::base::Exception);


    /** 
     * @brief Activates the thread-specific offscreen rendering context for the
     * current thread.
     */
    void activate(uint32_t i) throw (jwscxx::base::Exception);


    /** 
     * @brief Deactivates the thread-specific offscreen rendering context for
     * the current thread.
     */
    void deactivate(uint32_t i) throw (jwscxx::base::Exception);


    /** 
     * @brief Initializes the GL for use in the current offscreen rendering
     * context.
     */
    void init_gl();

}


#endif
