/**
 * This work is licensed under a Creative Commons 
 * Attribution-Noncommercial-Share Alike 3.0 United States License.
 * 
 *    http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 * 
 * You are free:
 * 
 *    to Share - to copy, distribute, display, and perform the work
 *    to Remix - to make derivative works
 * 
 * Under the following conditions:
 * 
 *    Attribution. You must attribute the work in the manner specified by the
 *    author or licensor (but not in any way that suggests that they endorse you
 *    or your use of the work).
 * 
 *    Noncommercial. You may not use this work for commercial purposes.
 * 
 *    Share Alike. If you alter, transform, or build upon this work, you may
 *    distribute the resulting work only under the same or similar license to
 *    this one.
 * 
 * For any reuse or distribution, you must make clear to others the license
 * terms of this work. The best way to do this is with a link to this web page.
 * 
 * Any of the above conditions can be waived if you get permission from the
 * copyright holder.
 * 
 * Apart from the remix rights granted under this license, nothing in this
 * license impairs or restricts the author's moral rights.
 */


/**
 * @file
 *
 * @author Joseph Schlecht
 *
 * @brief Interactive sampler visualization.
 */


#ifndef ONSCREEN_H
#define ONSCREEN_H


#include <config.h>

#include <inttypes.h>

#include "sampler.h"


namespace Onscreen
{

    /** @brief Enables onscreen rendering. */
    void enable
    (
        int          argc, 
        const char** argv, 
        const char*  title
    );


    /** @brief Returns whether onscreen rendering is enabled. */
    bool enabled();


    /** 
     * @brief Activates the onscreen rendering context for the current
     * thread.
     */
    void activate() throw (jwscxx::base::Exception);


    /** 
     * @brief Deactivates the onscreen rendering context for the current
     * thread.
     */
    void deactivate() throw (jwscxx::base::Exception);


    /** 
     * @brief Reactivates the onscreen rendering context for the current
     * thread.
     */
    void reactivate() throw (jwscxx::base::Exception);


    /** @brief Starts the onscreen interactive sampler. */
    void start
    (
        Sampler*             sampler,
        Sampler::Parameters* params
    );


    /** 
     * @brief Initializes the GL for use in the current onscreen rendering
     * context.
     */
    void init_gl();

}

#endif
