/**
 * This work is licensed under a Creative Commons 
 * Attribution-Noncommercial-Share Alike 3.0 United States License.
 * 
 *    http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 * 
 * You are free:
 * 
 *    to Share - to copy, distribute, display, and perform the work
 *    to Remix - to make derivative works
 * 
 * Under the following conditions:
 * 
 *    Attribution. You must attribute the work in the manner specified by the
 *    author or licensor (but not in any way that suggests that they endorse you
 *    or your use of the work).
 * 
 *    Noncommercial. You may not use this work for commercial purposes.
 * 
 *    Share Alike. If you alter, transform, or build upon this work, you may
 *    distribute the resulting work only under the same or similar license to
 *    this one.
 * 
 * For any reuse or distribution, you must make clear to others the license
 * terms of this work. The best way to do this is with a link to this web page.
 * 
 * Any of the above conditions can be waived if you get permission from the
 * copyright holder.
 * 
 * Apart from the remix rights granted under this license, nothing in this
 * license impairs or restricts the author's moral rights.
 */


/**
 * @file
 *
 * @author Joseph Schlecht
 *
 * @brief Functions to render various data structures in the GL.
 */


#ifndef RENDER_H
#define RENDER_H


#include <config.h>

#include <inttypes.h>

#include "view.h"
#include "object.h"


namespace Render
{

    /** @brief Renders the object model as a wire frame. */
    void wire_object(const View* view, const Object* obj);

    /** @brief Renders the object model as a solid object. */
    void solid_object(const View* view, const Object* obj);

    /** @brief Renders an input image. */
    void image(uint32_t i, const View* view);

    /** @brief Renders a full resolution input image. */
    void full_image(uint32_t i, const View* view);

    /** @brief Renders a thresholded input image. */
    void thresh_image(uint32_t i, const View* view);

    /** @brief Renders input image edges. */
    void edges(uint32_t i, const View* view);

}

#endif
